# -*- encoding: utf-8 -*-
require 'spec_helper'
#絵地

describe GroundPicturesController do
  before do
    @admin = FactoryGirl.create :admin
    @user = FactoryGirl.create( :user_yas)
    @sp = FactoryGirl.create :system_picture
    @lg = FactoryGirl.create :license_group, :name => 'peta'
    @license = FactoryGirl.create :license, :license_group_id => @lg.id, :system_picture_id => @sp.id
    @author = FactoryGirl.create :author, :user_id => @user.id
    @artist = FactoryGirl.create :artist_yas, :author_id => @author.id
    @op = FactoryGirl.create :original_picture, :artist_id => @artist.id
    @p = FactoryGirl.create :picture, :original_picture_id => @op.id, :license_id => @license.id, :artist_id => @artist.id
    @rp = FactoryGirl.create :resource_picture, :artist_id => @artist.id, :license_id => @license.id, :original_picture_id => @op.id, :picture_id => @p.id
    @panel = FactoryGirl.create :panel, :author_id => @author.id
  end

if MagicNumber['run_mode'] == 1
  describe '一覧表示に於いて' do
    before do
      sign_in @user
      @gp = FactoryGirl.create :ground_picture, :panel_id => @panel.id, :picture_id => @p.id
      GroundPicture.stub(:list).and_return([@gp, @gp, @gp])
    end
    context 'パラメータpageについて' do
      it '@pageに値が入る' do
        get :index, :page => 5
        assigns(:page).should eq 5
      end
      it '省略されると@pageに1値が入る' do
        get :index
        assigns(:page).should eq 1
      end
      it '与えられたpage_sizeがセットされている' do
        get :index, :page_size => 15
        assigns(:page_size).should eq 15
      end
      it '省略されると@page_sizeにデフォルト値が入る' do
        get :index
        assigns(:page_size).should eq GroundPicture.default_page_size
      end
      it '最大を超えると@page_sizeにデフォルト最大値が入る' do
        get :index, :page_size => 1500
        assigns(:page_size).should eq GroundPicture.max_page_size
      end
      it '不正な値が入ると@page_sizeにデフォルト最大値が入る' do
        get :index, :page_size => 0
        assigns(:page_size).should eq GroundPicture.default_page_size
      end
    end
    context 'つつがなく終わるとき' do
      it 'ステータスコード200 OKを返す' do
        get :index
        response.should be_success 
      end
      it '絵地モデルに一覧を問い合わせている' do
        GroundPicture.should_receive(:list).exactly(1)
        get :index
      end
      it '@ground_picturesにリストを取得している' do
        get :index
        assigns(:ground_pictures).should have_at_least(3).items
      end
      context 'html形式' do
        it '@paginateにページ制御を取得している' do
          get :index
          assigns(:paginate).is_a?(Kaminari::PaginatableArray).should be_true
        end
        it 'indexテンプレートを描画する' do
          get :index
          response.should render_template("index")
        end
      end
      context 'json形式' do
        it 'jsonデータを返す' do
          get :index, :format => :json
          lambda{JSON.parse(response.body)}.should_not raise_error(JSON::ParserError)
        end
        it '絵地モデルにjson一覧出力オプションを問い合わせている' do
          GroundPicture.should_receive(:list_json_opt).exactly(1)
          get :index, :format => :json
        end
        it 'データがリスト構造になっている' do
          get :index, :format => :json
          json = JSON.parse response.body
          json.should have_at_least(3).items
        end
        it 'リストの先頭くらいは絵地っぽいものであって欲しい' do
          get :index, :format => :json
          json = JSON.parse response.body
          json.first.has_key?("panel_id").should be_true
          json.first.has_key?("picture_id").should be_true
          json.first.has_key?("z").should be_true
        end
      end
    end
    context 'ユーザ権限がないとき' do
      before do
        sign_out @user
      end
      context 'html形式' do
        it 'ステータスコード302 Foundを返す' do
          get :index
          response.status.should eq 302
        end
        it 'サインインページへ遷移する' do
          get :index
          response.should redirect_to '/users/sign_in'
        end
      end
      context 'json形式' do
        it 'ステータスコード401 Unauthorizedを返す' do
          get :index, :format => :json
          response.status.should eq 401
        end
        it '応答メッセージにUnauthorizedを返す' do
          get :index, :format => :json
          response.message.should match(/Unauthorized/)
        end
      end
    end
    context 'ユーザ権限はないが管理者権限があるとき' do
      before do
        sign_out @user
        sign_in @admin
      end
      it 'ステータスコード200 OKを返す' do
        get :index
        response.should be_success 
      end
    end
    context 'ユーザだが作家登録していないとき' do
      before do
        @author.destroy
      end
      it 'ステータスコード200 OKを返す' do
        get :index
        response.should be_success 
      end
    end
  end
  
  describe '単体表示に於いて' do
    before do
      sign_in @user
      @gp = FactoryGirl.create :ground_picture, :panel_id => @panel.id, :picture_id => @p.id
      GroundPicture.stub(:show).and_return(@gp)
    end
    context 'つつがなく終わるとき' do
      it 'ステータスコード200 OKを返す' do
        get :show, :id => @gp.id
        response.should be_success
      end
      it '絵地モデルに単体取得を問い合わせている' do
        GroundPicture.should_receive(:show).exactly(1)
        get :show
      end
      it '@ground_pictureにアレを取得している' do
        get :show, :id => @gp.id
        assigns(:ground_picture).should eq(@gp)
      end
      context 'html形式' do
        it 'showテンプレートを描画する' do
          get :show, :id => @gp.id
          response.should render_template("show")
        end
      end
      context 'json形式' do
        it 'jsonデータを返す' do
          get :show, :id => @gp.id, :format => :json
          lambda{JSON.parse(response.body)}.should_not raise_error(JSON::ParserError)
        end
        it '絵地モデルにjson単体出力オプションを問い合わせている' do
          GroundPicture.should_receive(:show_json_opt).exactly(1)
          get :show, :id => @gp.id, :format => :json
        end
        it 'データがアレになっている' do
          get :show, :id => @gp.id, :format => :json
          json = JSON.parse response.body
          json["panel_id"].should_not be_nil
          json["z"].should_not be_nil
          json["picture_id"].should_not be_nil
        end
      end
    end
    context 'ユーザ権限がないとき' do
      before do
        sign_out @user
      end
      context 'html形式' do
        it 'ステータスコード302 Foundを返す' do
          get :show, :id => @gp.id
          response.status.should eq 302
        end
        it 'サインインページへ遷移する' do
          get :show, :id => @gp.id
          response.body.should redirect_to '/users/sign_in'
        end
      end
      context 'json形式' do
        it 'ステータスコード401 Unauthorizedを返す' do
          get :show, :id => @gp.id, :format => :json
          response.status.should eq 401
        end
        it '応答メッセージにUnauthorizedを返す' do
          get :show, :id => @gp.id, :format => :json
          response.message.should match(/Unauthorized/)
        end
      end
    end
    context 'ユーザ権限はないが管理者権限があるとき' do
      before do
        sign_out @user
        sign_in @admin
      end
      it 'ステータスコード200 OKを返す' do
        get :show, :id => @gp.id
        response.should be_success 
      end
    end
    context 'ユーザだが作家登録していないとき' do
      before do
        @author.destroy
      end
      it 'ステータスコード200 OKを返す' do
        get :show, :id => @gp.id
        response.should be_success 
      end
    end
  end
  
else
  describe '一覧表示に於いて' do
    before do
      sign_in @user
      @gp = FactoryGirl.create :ground_picture, :panel_id => @panel.id, :picture_id => @p.id
      GroundPicture.stub(:list).and_return([@gp, @gp, @gp])
    end
    context 'つつがなく終わるとき' do
      it 'ステータスコード200 OKを返す' do
        get :index
        response.should be_success 
      end
      context 'html形式' do
        it 'indexテンプレートを描画する' do
          get :index
          response.should render_template("index")
        end
      end
      context 'json形式' do
        it 'jsonデータを返す' do
          get :index, :format => :json
          lambda{JSON.parse(response.body)}.should_not raise_error(JSON::ParserError)
        end
      end
    end
    context 'ユーザ権限がないとき' do
      before do
        sign_out @user
      end
      it 'ステータスコード200 OKを返す' do
        get :index
        response.should be_success 
      end
      context 'html形式' do
        it 'indexテンプレートを描画する' do
          get :index
          response.should render_template("index")
        end
      end
      context 'json形式' do
        it 'jsonデータを返す' do
          get :index, :format => :json
          lambda{JSON.parse(response.body)}.should_not raise_error(JSON::ParserError)
        end
      end
    end
  end
  
  describe '単体表示に於いて' do
    before do
      sign_in @user
      @gp = FactoryGirl.create :ground_picture, :panel_id => @panel.id, :picture_id => @p.id
      GroundPicture.stub(:show).and_return(@gp)
    end
    context 'つつがなく終わるとき' do
      it 'ステータスコード200 OKを返す' do
        get :show, :id => @gp.id
        response.should be_success
      end
      context 'html形式' do
        it 'showテンプレートを描画する' do
          get :show, :id => @gp.id
          response.should render_template("show")
        end
      end
      context 'json形式' do
        it 'jsonデータを返す' do
          get :show, :id => @gp.id, :format => :json
          lambda{JSON.parse(response.body)}.should_not raise_error(JSON::ParserError)
        end
      end
    end
    context 'ユーザ権限がないとき' do
      before do
        sign_out @user
      end
      it 'ステータスコード200 OKを返す' do
        get :show, :id => @gp.id
        response.should be_success
      end
      context 'html形式' do
        it 'showテンプレートを描画する' do
          get :show, :id => @gp.id
          response.should render_template("show")
        end
      end
      context 'json形式' do
        it 'jsonデータを返す' do
          get :show, :id => @gp.id, :format => :json
          lambda{JSON.parse(response.body)}.should_not raise_error(JSON::ParserError)
        end
      end
    end
  end
  
end
end
